@@ -6,6 +6,13 @@
 #include <iomanip>
 #include <sstream>
 
+#if !defined(CPP_UTILITIES_CHRONO_BASED_EXACT_TIME) && (defined(PLATFORM_MAC) || !defined(PLATFORM_UNIX))
+#define CPP_UTILITIES_CHRONO_BASED_EXACT_TIME
+#endif
+#ifdef CPP_UTILITIES_CHRONO_BASED_EXACT_TIME
+#include <chrono>
+#endif
+
 using namespace std;
 
 namespace CppUtilities {
@@ -39,15 +46,16 @@ template <typename num1, typename num2, typename num3> constexpr bool inRangeExc
  *  - Time values are measured in 100-nanosecond units called ticks,
  *    and a particular date is the number of ticks since 12:00 midnight, January 1,
  *    0001 A.D. (C.E.) in the Gregorian Calendar (excluding ticks that would be added by leap seconds).
- *  - There is no time zone information associated. You need to keep track of the used time zone separately. That can
- *    be done by keeping an additional TimeSpan around which represents the delta to GMT or by simply using GMT everywhere
- *    in the program.
+ *  - There is no time zone information associated. You need to keep track of the used time zone separately. That can be done by
+ *    keeping an additional TimeSpan around which represents the delta to UTC. For this one can also use DateTimeExpression.
+ *    Alternatively, one can simply use UTC everywhere in the program.
+ *  - Many functions/descriptions refer to GMT instead of UTC. Both terms are used interchangeably here as the difference is not
+ *    relevant here. Note that GMT does *not* mean "time in Greenwich".
  *  - When constructing an instance via DateTime::fromTimeStamp(), DateTime::fromChronoTimePoint() or DateTime::fromIsoStringLocal()
  *    the time zone deltas are "baked into" the DateTime instance. For instance, the expression (DateTime::now() - DateTime::gmtNow())
  *    returns one hour in Germany during winter time (and *not* zero although both instances represent the current time).
  * \todo
- * - Allow to determine the date part for each component at once to prevent multiple
- *   invocations of getDatePart().
+ * - Allow to determine the date part for each component at once to prevent multiple invocations of getDatePart().
  */
 
 /*!
@@ -270,19 +278,23 @@ const char *DateTime::printDayOfWeek(DayOfWeek dayOfWeek, bool abbreviation)
     return "";
 }
 
-#if defined(PLATFORM_UNIX) && !defined(PLATFORM_MAC)
 /*!
  * \brief Returns a DateTime object that is set to the current date and time on this computer, expressed as the GMT time.
- * \remarks Only available under UNIX-like systems supporting clock_gettime().
  */
 DateTime DateTime::exactGmtNow()
 {
+#ifdef CPP_UTILITIES_CHRONO_BASED_EXACT_TIME
+    return DateTime(DateTime::unixEpochStart().totalTicks()
+        + static_cast<std::uint64_t>(
+              std::chrono::time_point_cast<std::chrono::nanoseconds>(std::chrono::high_resolution_clock::now()).time_since_epoch().count())
+            / 100);
+#else
     struct timespec t;
     clock_gettime(CLOCK_REALTIME, &t);
     return DateTime(DateTime::unixEpochStart().totalTicks() + static_cast<std::uint64_t>(t.tv_sec) * TimeSpan::ticksPerSecond
         + static_cast<std::uint64_t>(t.tv_nsec) / 100);
-}
 #endif
+}
 
 /*!
  * \brief Converts the given date expressed in \a year, \a month and \a day to ticks.
